export class StaticAssets {
    constructor(assetsMap) {
        this.assetsMap = assetsMap;
    }
    getAsset(key) {
        return this.assetsMap[key];
    }
    serveAsset(asset) {
        // Aggressive caching for static files, and no caching for everything else.
        const headers = {
            'Cache-Control': asset.isStatic ? 'max-age=31536000' : 'no-cache',
        };
        if (asset.contentType != null) {
            headers['Content-Type'] = asset.contentType;
        }
        return new Response(asset.content, {
            status: 200,
            headers,
        });
    }
    serveAssetForEvent(event, pathPrefix = '') {
        const { request } = event;
        const { pathname } = new URL(request.url);
        const asset = this.getAsset(`${pathPrefix}${pathname}`);
        if (!asset) {
            return null;
        }
        return this.serveAsset(asset);
    }
}
